@@ -2,7 +2,7 @@ package PICA::Data;
 use strict;
 use warnings;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(pica_parser pica_writer pica_path pica_xml_struct
@@ -13,7 +13,7 @@ our $ILN_PATH = PICA::Path->new('101@a');
 our $EPN_PATH = PICA::Path->new('203@/**0');
 
 use Carp qw(croak);
-use Scalar::Util qw(reftype);
+use Scalar::Util qw(reftype blessed);
 use List::Util qw(first);
 use IO::Handle;
 use PICA::Path;
@@ -166,6 +166,25 @@ sub _pica_module {
     }
 }
 
+sub write {
+    my $pica = shift;
+    my $writer = $_[0];
+    unless (blessed $writer) {
+        $writer = pica_writer(@_ ? @_ : 'plain');
+    }
+    $writer->write($pica);
+}
+
+sub string {
+    my ($pica, $type, %options) = @_;
+    my $string = "";
+    $type ||= 'plain';
+    $options{fh} = \$string;
+    $options{start} //= 0;
+    pica_writer( $type => %options )->write($pica);
+    return $string;
+}
+
 sub pica_xml_struct {
     my ($xml, %options) = @_;
     my $record;
@@ -202,8 +221,8 @@ PICA::Data - PICA record processing
 =head1 SYNOPSIS
 
     use PICA::Data ':all';
-    $parser = pica_parser( xml => @options );
-    $writer = pica_writer( plain => @options );
+    $parser = pica_parser( xml => 'picadata.xml' );
+    $writer = pica_writer( plain => \*STDOUT );
    
     use PICA::Parser::XML;
     use PICA::Writer::Plain;
@@ -228,6 +247,15 @@ PICA::Data - PICA record processing
 
         # write record
         $writer->write($record);
+        
+        # write record via method (if blessed)
+        $record->write($writer);
+        $record->write( xml => @options );
+        $record->write; # default "plain" writer
+
+        # stringify record
+        my $plain = $record->string;
+        my $xml = $record->string('xml');
     }
   
     # parse single record from string
@@ -272,8 +300,8 @@ get all of them):
 
 =head2 pica_parser( $type [, @options] )
 
-Create a PICA parsers object. Case of the type is ignored and additional
-parameters are passed to the parser's constructor:
+Create a PICA parsers object (see L<PICA::Parser::Base>). Case of the type is
+ignored and additional parameters are passed to the parser's constructor:
 
 =over
 
@@ -298,7 +326,8 @@ blessed) PICA record structure.
 
 =head2 pica_writer( $type [, @options] )
 
-Create a PICA writer object in the same way as C<pica_parser> with one of
+Create a PICA writer object (see L<PICA::Writer::Base>) in the same way as
+C<pica_parser> with one of
 
 =over
 
@@ -373,7 +402,18 @@ where the C<_id> of each record contains the ILN (subfield C<101@a>).
 
 Returns a list (as array reference) of item records (level 1),
 where the C<_id> of each record contains the EPN (subfield C<203@/**0>).
- 
+
+=head1 METHODS
+
+=head2 write( [ $type [, @options] ] | $writer )
+
+Write PICA record with given L<PICA::Writer::Base|PICA::Writer::> or
+PICA::Writer::Plain by default. This method is a shortcut for blessed
+record objects:
+
+    pica_writer( xml => $file )->write( $record );
+    $record->write( xml => $file ); # equivalent if $record is blessed 
+
 =head1 CONTRIBUTORS
 
 Johann Rolschewski, C<< <rolschewski@gmail.com> >>
